@@ -112,6 +112,12 @@ then
     /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/webdav.conf /etc/lighttpd/conf.d/webdav.conf
 fi
 
+if [ ! -e /etc/lighttpd/lighttpd.annotated.conf ]
+then
+    /usr/bin/mkdir -p /etc/lighttpd
+    /usr/bin/cp /etc/defaults/etc/lighttpd/lighttpd.annotated.conf /etc/lighttpd/lighttpd.annotated.conf
+fi
+
 if [ ! -e /etc/lighttpd/lighttpd.conf ]
 then
     /usr/bin/mkdir -p /etc/lighttpd
