@@ -93,6 +93,11 @@ then
     rm /etc/lighttpd/conf.d/webdav.conf
 fi
 
+if [ -f /etc/lighttpd/lighttpd.annotated.conf ] && cmp -s /etc/defaults/etc/lighttpd/lighttpd.annotated.conf /etc/lighttpd/lighttpd.annotated.conf
+then
+    rm /etc/lighttpd/lighttpd.annotated.conf
+fi
+
 if [ -f /etc/lighttpd/lighttpd.conf ] && cmp -s /etc/defaults/etc/lighttpd/lighttpd.conf /etc/lighttpd/lighttpd.conf
 then
     rm /etc/lighttpd/lighttpd.conf
